-file("/Users/sqrt/.asdf/installs/erlang/20.1/lib/erlang/lib/parsetools-2.1.5/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(pgn_lexer).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("src/pgn_lexer.xrl", 54).

-file("/Users/sqrt/.asdf/installs/erlang/20.1/lib/erlang/lib/parsetools-2.1.5/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,Tlen,_Ics1,L1,_S1} ->
            Tcs1 = yysuf(Tcs, Alen),
            L2 = adjust_line(Tlen, Alen, Tcs1, L1),
            string_cont(Tcs1, L2, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->       % Use last accept match
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            token_cont(Tcs1, L2, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            tokens_cont(Tcs1, L2, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            skip_cont(Tcs1, L2, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% adjust_line(TokenLength, AcceptLength, Chars, Line) -> NewLine
%% Make sure that newlines in Chars are not counted twice.
%% Line has been updated with respect to newlines in the prefix of
%% Chars consisting of (TokenLength - AcceptLength) characters.

adjust_line(N, N, _Cs, L) -> L;
adjust_line(T, A, [$\n|Cs], L) ->
    adjust_line(T-1, A, Cs, L-1);
adjust_line(T, A, [_|Cs], L) ->
    adjust_line(T-1, A, Cs, L).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("src/pgn_lexer.erl", 303).
yystate() -> 74.

yystate(81, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(73, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(81, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 104 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(81, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,81};
yystate(80, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(72, Ics, Line, Tlen+1, Action, Alen);
yystate(80, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,80};
yystate(79, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(79, Ics, Line+1, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(79, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 92 ->
    yystate(79, Ics, Line, Tlen+1, Action, Alen);
yystate(79, [C|Ics], Line, Tlen, Action, Alen) when C >= 94 ->
    yystate(79, Ics, Line, Tlen+1, Action, Alen);
yystate(79, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,79};
yystate(78, [32|Ics], Line, Tlen, _, _) ->
    yystate(78, Ics, Line, Tlen+1, 12, Tlen);
yystate(78, [9|Ics], Line, Tlen, _, _) ->
    yystate(78, Ics, Line, Tlen+1, 12, Tlen);
yystate(78, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,78};
yystate(77, [112|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(77, [80|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(77, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(77, [C|Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 56 ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(77, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,77};
yystate(76, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(80, Ics, Line, Tlen+1, Action, Alen);
yystate(76, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(64, Ics, Line, Tlen+1, Action, Alen);
yystate(76, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,76};
yystate(75, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(75, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(75, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(75, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 104 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(75, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,75};
yystate(74, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [123|Ics], Line, Tlen, _, _) ->
    yystate(50, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [120|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [91|Ics], Line, Tlen, _, _) ->
    yystate(79, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [79|Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [78|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [75|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [66|Ics], Line, Tlen, _, _) ->
    yystate(23, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [63|Ics], Line, Tlen, _, _) ->
    yystate(54, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [61|Ics], Line, Tlen, _, _) ->
    yystate(3, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [59|Ics], Line, Tlen, _, _) ->
    yystate(35, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [57|Ics], Line, Tlen, _, _) ->
    yystate(43, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [49|Ics], Line, Tlen, _, _) ->
    yystate(81, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [48|Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [43|Ics], Line, Tlen, _, _) ->
    yystate(6, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [42|Ics], Line, Tlen, _, _) ->
    yystate(22, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [41|Ics], Line, Tlen, _, _) ->
    yystate(30, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [40|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [36|Ics], Line, Tlen, _, _) ->
    yystate(46, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [33|Ics], Line, Tlen, _, _) ->
    yystate(54, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [32|Ics], Line, Tlen, _, _) ->
    yystate(78, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [13|Ics], Line, Tlen, _, _) ->
    yystate(70, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [10|Ics], Line, Tlen, _, _) ->
    yystate(70, Ics, Line+1, Tlen+1, 2, Tlen);
yystate(74, [9|Ics], Line, Tlen, _, _) ->
    yystate(78, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 50, C =< 56 ->
    yystate(75, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 80, C =< 82 ->
    yystate(23, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(61, Ics, Line, Tlen+1, 2, Tlen);
yystate(74, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,74};
yystate(73, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen+1, Action, Alen);
yystate(73, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,73};
yystate(72, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(72, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(72, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,72};
yystate(71, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line};
yystate(70, [13|Ics], Line, Tlen, _, _) ->
    yystate(70, Ics, Line, Tlen+1, 13, Tlen);
yystate(70, [10|Ics], Line, Tlen, _, _) ->
    yystate(70, Ics, Line+1, Tlen+1, 13, Tlen);
yystate(70, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line,70};
yystate(69, [120|Ics], Line, Tlen, _, _) ->
    yystate(34, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [101|Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [69|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [61|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [43|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [35|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [32|Ics], Line, Tlen, _, _) ->
    yystate(53, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(26, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, [C|Ics], Line, Tlen, _, _) when C >= 102, C =< 104 ->
    yystate(26, Ics, Line, Tlen+1, 5, Tlen);
yystate(69, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,69};
yystate(68, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(68, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(68, [45|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 2, Tlen);
yystate(68, [43|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 2, Tlen);
yystate(68, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,68};
yystate(67, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line};
yystate(66, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line};
yystate(65, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(65, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,65};
yystate(64, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [45|Ics], Line, Tlen, _, _) ->
    yystate(56, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [43|Ics], Line, Tlen, _, _) ->
    yystate(48, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,64};
yystate(63, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(63, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,63};
yystate(62, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line};
yystate(61, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 56 ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(61, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 104 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(61, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,61};
yystate(60, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(60, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,60};
yystate(59, [46|Ics], Line, Tlen, _, _) ->
    yystate(67, Ics, Line, Tlen+1, 4, Tlen);
yystate(59, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,59};
yystate(58, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(58, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,58};
yystate(57, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(57, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,57};
yystate(56, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(80, Ics, Line, Tlen+1, Action, Alen);
yystate(56, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,56};
yystate(55, [79|Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(55, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,55};
yystate(54, [63|Ics], Line, Tlen, _, _) ->
    yystate(62, Ics, Line, Tlen+1, 8, Tlen);
yystate(54, [33|Ics], Line, Tlen, _, _) ->
    yystate(62, Ics, Line, Tlen+1, 8, Tlen);
yystate(54, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line,54};
yystate(53, [101|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(53, [69|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(53, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(53, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,53};
yystate(52, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(52, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(52, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,52};
yystate(51, [46|Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen+1, 4, Tlen);
yystate(51, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,51};
yystate(50, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(42, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line+1, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 124 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 126 ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(50, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,50};
yystate(49, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(49, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,49};
yystate(48, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(40, Ics, Line, Tlen+1, Action, Alen);
yystate(48, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,48};
yystate(47, [45|Ics], Line, Tlen, _, _) ->
    yystate(39, Ics, Line, Tlen+1, 10, Tlen);
yystate(47, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line,47};
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(46, Ics, Line, Tlen+1, 9, Tlen);
yystate(46, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line,46};
yystate(45, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line};
yystate(44, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(44, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(44, [61|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 2, Tlen);
yystate(44, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(44, [43|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 2, Tlen);
yystate(44, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,44};
yystate(43, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(43, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(43, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,43};
yystate(42, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line};
yystate(41, [50|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(41, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,41};
yystate(40, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(40, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,40};
yystate(39, [79|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(39, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,39};
yystate(38, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line};
yystate(37, [45|Ics], Line, Tlen, _, _) ->
    yystate(45, Ics, Line, Tlen+1, 5, Tlen);
yystate(37, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,37};
yystate(36, [61|Ics], Line, Tlen, Action, Alen) ->
    yystate(44, Ics, Line, Tlen+1, Action, Alen);
yystate(36, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(36, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,36};
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(35, Ics, Line, Tlen+1, 7, Tlen);
yystate(35, [C|Ics], Line, Tlen, _, _) when C >= 11 ->
    yystate(35, Ics, Line, Tlen+1, 7, Tlen);
yystate(35, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,35};
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 104 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(34, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,34};
yystate(33, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(33, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,33};
yystate(32, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(32, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(32, [45|Ics], Line, Tlen, _, _) ->
    yystate(56, Ics, Line, Tlen+1, 2, Tlen);
yystate(32, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,32};
yystate(31, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line};
yystate(30, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line};
yystate(29, [43|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(29, [35|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(29, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,29};
yystate(28, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(28, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(28, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,28};
yystate(27, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(27, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(27, [47|Ics], Line, Tlen, _, _) ->
    yystate(60, Ics, Line, Tlen+1, 2, Tlen);
yystate(27, [45|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 2, Tlen);
yystate(27, [43|Ics], Line, Tlen, _, _) ->
    yystate(16, Ics, Line, Tlen+1, 2, Tlen);
yystate(27, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,27};
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 56 ->
    yystate(18, Ics, Line, Tlen+1, Action, Alen);
yystate(26, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,26};
yystate(25, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(17, Ics, Line, Tlen+1, Action, Alen);
yystate(25, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,25};
yystate(24, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(24, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(24, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(24, [43|Ics], Line, Tlen, _, _) ->
    yystate(16, Ics, Line, Tlen+1, 2, Tlen);
yystate(24, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,24};
yystate(23, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 56 ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(23, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 104 ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(23, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,23};
yystate(22, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line};
yystate(21, [81|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [82|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [78|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(21, [66|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(21, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,21};
yystate(20, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(8, Ics, Line, Tlen+1, Action, Alen);
yystate(20, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,20};
yystate(19, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(19, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(19, [47|Ics], Line, Tlen, _, _) ->
    yystate(80, Ics, Line, Tlen+1, 2, Tlen);
yystate(19, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(19, [43|Ics], Line, Tlen, _, _) ->
    yystate(27, Ics, Line, Tlen+1, 2, Tlen);
yystate(19, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,19};
yystate(18, [101|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 5, Tlen);
yystate(18, [69|Ics], Line, Tlen, _, _) ->
    yystate(10, Ics, Line, Tlen+1, 5, Tlen);
yystate(18, [61|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 5, Tlen);
yystate(18, [43|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(18, [35|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(18, [32|Ics], Line, Tlen, _, _) ->
    yystate(53, Ics, Line, Tlen+1, 5, Tlen);
yystate(18, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,18};
yystate(17, [49|Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(17, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,17};
yystate(16, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(60, Ics, Line, Tlen+1, Action, Alen);
yystate(16, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,16};
yystate(15, [120|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(15, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 104 ->
    yystate(26, Ics, Line, Tlen+1, Action, Alen);
yystate(15, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,15};
yystate(14, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(14, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(14, [61|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 2, Tlen);
yystate(14, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(14, [43|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 2, Tlen);
yystate(14, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,14};
yystate(13, [112|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(13, [80|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(13, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,13};
yystate(12, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(12, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(12, [61|Ics], Line, Tlen, _, _) ->
    yystate(20, Ics, Line, Tlen+1, 2, Tlen);
yystate(12, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(12, [43|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 2, Tlen);
yystate(12, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,12};
yystate(11, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(11, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(11, [61|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 2, Tlen);
yystate(11, [47|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 2, Tlen);
yystate(11, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(11, [43|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 2, Tlen);
yystate(11, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,11};
yystate(10, [112|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [80|Ics], Line, Tlen, Action, Alen) ->
    yystate(2, Ics, Line, Tlen+1, Action, Alen);
yystate(10, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(13, Ics, Line, Tlen+1, Action, Alen);
yystate(10, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,10};
yystate(9, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(80, Ics, Line, Tlen+1, Action, Alen);
yystate(9, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(9, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,9};
yystate(8, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(8, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,8};
yystate(7, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(7, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(7, [61|Ics], Line, Tlen, _, _) ->
    yystate(11, Ics, Line, Tlen+1, 2, Tlen);
yystate(7, [47|Ics], Line, Tlen, _, _) ->
    yystate(36, Ics, Line, Tlen+1, 2, Tlen);
yystate(7, [45|Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen+1, 2, Tlen);
yystate(7, [43|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 2, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,7};
yystate(6, [61|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(6, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(24, Ics, Line, Tlen+1, Action, Alen);
yystate(6, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,6};
yystate(5, [61|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, [43|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, [35|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, [32|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 5, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,5};
yystate(4, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(8, Ics, Line, Tlen+1, Action, Alen);
yystate(4, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(4, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,4};
yystate(3, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(3, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(3, [61|Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen+1, 2, Tlen);
yystate(3, [47|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 2, Tlen);
yystate(3, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(3, [43|Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen+1, 2, Tlen);
yystate(3, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,3};
yystate(2, [61|Ics], Line, Tlen, _, _) ->
    yystate(21, Ics, Line, Tlen+1, 5, Tlen);
yystate(2, [46|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 5, Tlen);
yystate(2, [43|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(2, [35|Ics], Line, Tlen, _, _) ->
    yystate(37, Ics, Line, Tlen+1, 5, Tlen);
yystate(2, [32|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 5, Tlen);
yystate(2, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,2};
yystate(1, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(1, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(1, [45|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 2, Tlen);
yystate(1, [43|Ics], Line, Tlen, _, _) ->
    yystate(16, Ics, Line, Tlen+1, 2, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,1};
yystate(0, [8723|Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen+1, 2, Tlen);
yystate(0, [177|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 2, Tlen);
yystate(0, [45|Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen+1, 2, Tlen);
yystate(0, [43|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 2, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, _, _, TokenLine) ->
    yyaction_0(TokenLine);
yyaction(1, _, _, TokenLine) ->
    yyaction_1(TokenLine);
yyaction(2, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_2(TokenChars, TokenLine);
yyaction(3, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_3(TokenChars, TokenLine);
yyaction(4, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_4(TokenChars, TokenLine);
yyaction(5, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_5(TokenChars, TokenLine);
yyaction(6, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_6(TokenChars, TokenLine);
yyaction(7, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_7(TokenChars, TokenLine);
yyaction(8, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_8(TokenChars, TokenLine);
yyaction(9, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_9(TokenChars, TokenLine);
yyaction(10, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_10(TokenChars, TokenLine);
yyaction(11, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_11(TokenChars, TokenLine);
yyaction(12, _, _, _) ->
    yyaction_12();
yyaction(13, _, _, _) ->
    yyaction_13();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/1}).
-file("src/pgn_lexer.xrl", 29).
yyaction_0(TokenLine) ->
     { token, { '(', TokenLine } } .

-compile({inline,yyaction_1/1}).
-file("src/pgn_lexer.xrl", 30).
yyaction_1(TokenLine) ->
     { token, { ')', TokenLine } } .

-compile({inline,yyaction_2/2}).
-file("src/pgn_lexer.xrl", 32).
yyaction_2(TokenChars, TokenLine) ->
     { token, { pos_eval, TokenLine, TokenChars } } .

-compile({inline,yyaction_3/2}).
-file("src/pgn_lexer.xrl", 34).
yyaction_3(TokenChars, TokenLine) ->
     { token, { tag, TokenLine, TokenChars } } .

-compile({inline,yyaction_4/2}).
-file("src/pgn_lexer.xrl", 35).
yyaction_4(TokenChars, TokenLine) ->
     { token, { move, TokenLine, TokenChars } } .

-compile({inline,yyaction_5/2}).
-file("src/pgn_lexer.xrl", 36).
yyaction_5(TokenChars, TokenLine) ->
     { token, { san, TokenLine, TokenChars } } .

-compile({inline,yyaction_6/2}).
-file("src/pgn_lexer.xrl", 37).
yyaction_6(TokenChars, TokenLine) ->
     { token, { comment, TokenLine, TokenChars } } .

-compile({inline,yyaction_7/2}).
-file("src/pgn_lexer.xrl", 38).
yyaction_7(TokenChars, TokenLine) ->
     { token, { comment, TokenLine, TokenChars } } .

-compile({inline,yyaction_8/2}).
-file("src/pgn_lexer.xrl", 39).
yyaction_8(TokenChars, TokenLine) ->
     { token, { move_eval, TokenLine, TokenChars } } .

-compile({inline,yyaction_9/2}).
-file("src/pgn_lexer.xrl", 41).
yyaction_9(TokenChars, TokenLine) ->
     { token, { nag, TokenLine, TokenChars } } .

-compile({inline,yyaction_10/2}).
-file("src/pgn_lexer.xrl", 42).
yyaction_10(TokenChars, TokenLine) ->
     { token, { san, TokenLine, TokenChars } } .

-compile({inline,yyaction_11/2}).
-file("src/pgn_lexer.xrl", 43).
yyaction_11(TokenChars, TokenLine) ->
     { token, { result, TokenLine, TokenChars } } .

-compile({inline,yyaction_12/0}).
-file("src/pgn_lexer.xrl", 45).
yyaction_12() ->
     skip_token .

-compile({inline,yyaction_13/0}).
-file("src/pgn_lexer.xrl", 46).
yyaction_13() ->
     skip_token .

-file("/Users/sqrt/.asdf/installs/erlang/20.1/lib/erlang/lib/parsetools-2.1.5/include/leexinc.hrl", 309).
